@@ -5,6 +5,7 @@ from sys import argv
 from os import walk
 from os.path import exists as path_exists, join as path_join
 from json import dumps as json_dump, loads as json_load
+import re
 import argparse
 from config import __version__
 
@@ -18,6 +19,10 @@ def __dump_json__(file_path, json):
         file.write(json_dump(json, indent=3))
 
 
+def __convert_str_to_list(value):
+    return value.strip("][").split(',')
+
+
 def __wait_confirmation__(message: str) -> bool:
     print(f"{message} (y/n)")
     answer = input()
@@ -67,18 +72,15 @@ def create_command(params):
     global_template = template
     config = __parse_template__(template)
 
-    print(f"{config=}")
     if params.extra_vars:
-        types = {"int": int, "list": list, "str": str, "none": str, None: str}
+        types = {"<int>": int, "<list>": __convert_str_to_list, "<str>": str, "None": str, None: str, "<bool>": bool}
         for i in params.extra_vars:
             path, value = i.split("=")
             path = path.split('/')
-            value = value.split(":")
-            if len(value) == 2:
-                type_value = value[1]
-            else:
-                type_value = None
-            value = value[0]
+            type_value = re.search(r"<\w+>", value)
+            value = value.split("<")[0]
+            if type_value:
+                type_value = type_value.group(0)
             element = __walk_on_json_path__("/".join(path[:-1]), config, config)
             element[path[-1]] = types[type_value](value)
 
